# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PrivateStreetNoticeResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'private_street_reference_number': 'str',
        'proposed_start_date': 'datetime',
        'proposed_end_date': 'datetime',
        'private_street_status': 'PrivateStreetStatusResponse',
        'private_street_status_string': 'str',
        'work_reference_number': 'str',
        'promoter_organisation': 'str',
        'promoter_swa_code': 'str',
        'secondary_contact': 'str',
        'secondary_contact_number': 'str',
        'secondary_contact_email': 'str',
        'proposed_start_time': 'datetime',
        'proposed_end_time': 'datetime',
        'calendar_day_duration': 'float',
        'working_day_duration': 'float',
        'description_of_work': 'str',
        'excavation': 'bool',
        'project_reference_number': 'str',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'usrn': 'str',
        'highway_authority': 'str',
        'highway_authority_swa_code': 'str',
        'works_location_description': 'str',
        'works_coordinates': 'object',
        'date_created': 'datetime',
        'date_modified': 'datetime',
        'traffic_management_type': 'TrafficManagementTypeResponse',
        'traffic_management_type_string': 'str',
        'location_types': 'list[LocationTypeResponse]',
        'location_types_string': 'list[str]',
        'files': 'list[FileSummaryResponse]',
        'workstream_prefix': 'str',
        'close_footway': 'CloseFootwayResponse',
        'close_footway_string': 'str',
        'work_status': 'WorkStatusResponse',
        'work_status_string': 'str',
        'additional_contact': 'str',
        'additional_contact_number': 'str',
        'additional_contact_email': 'str',
        'emergency_contact_name': 'str',
        'emergency_contact_number': 'str',
        'close_footpath': 'CloseFootpathResponse',
        'close_footpath_string': 'str',
        'street_line': 'object',
        'road_category': 'float'
    }

    attribute_map = {
        'private_street_reference_number': 'private_street_reference_number',
        'proposed_start_date': 'proposed_start_date',
        'proposed_end_date': 'proposed_end_date',
        'private_street_status': 'private_street_status',
        'private_street_status_string': 'private_street_status_string',
        'work_reference_number': 'work_reference_number',
        'promoter_organisation': 'promoter_organisation',
        'promoter_swa_code': 'promoter_swa_code',
        'secondary_contact': 'secondary_contact',
        'secondary_contact_number': 'secondary_contact_number',
        'secondary_contact_email': 'secondary_contact_email',
        'proposed_start_time': 'proposed_start_time',
        'proposed_end_time': 'proposed_end_time',
        'calendar_day_duration': 'calendar_day_duration',
        'working_day_duration': 'working_day_duration',
        'description_of_work': 'description_of_work',
        'excavation': 'excavation',
        'project_reference_number': 'project_reference_number',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'usrn': 'usrn',
        'highway_authority': 'highway_authority',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'works_location_description': 'works_location_description',
        'works_coordinates': 'works_coordinates',
        'date_created': 'date_created',
        'date_modified': 'date_modified',
        'traffic_management_type': 'traffic_management_type',
        'traffic_management_type_string': 'traffic_management_type_string',
        'location_types': 'location_types',
        'location_types_string': 'location_types_string',
        'files': 'files',
        'workstream_prefix': 'workstream_prefix',
        'close_footway': 'close_footway',
        'close_footway_string': 'close_footway_string',
        'work_status': 'work_status',
        'work_status_string': 'work_status_string',
        'additional_contact': 'additional_contact',
        'additional_contact_number': 'additional_contact_number',
        'additional_contact_email': 'additional_contact_email',
        'emergency_contact_name': 'emergency_contact_name',
        'emergency_contact_number': 'emergency_contact_number',
        'close_footpath': 'close_footpath',
        'close_footpath_string': 'close_footpath_string',
        'street_line': 'street_line',
        'road_category': 'road_category'
    }

    def __init__(self, private_street_reference_number=None, proposed_start_date=None, proposed_end_date=None, private_street_status=None, private_street_status_string=None, work_reference_number=None, promoter_organisation=None, promoter_swa_code=None, secondary_contact=None, secondary_contact_number=None, secondary_contact_email=None, proposed_start_time=None, proposed_end_time=None, calendar_day_duration=None, working_day_duration=None, description_of_work=None, excavation=None, project_reference_number=None, street_name=None, town=None, area_name=None, usrn=None, highway_authority=None, highway_authority_swa_code=None, works_location_description=None, works_coordinates=None, date_created=None, date_modified=None, traffic_management_type=None, traffic_management_type_string=None, location_types=None, location_types_string=None, files=None, workstream_prefix=None, close_footway=None, close_footway_string=None, work_status=None, work_status_string=None, additional_contact=None, additional_contact_number=None, additional_contact_email=None, emergency_contact_name=None, emergency_contact_number=None, close_footpath=None, close_footpath_string=None, street_line=None, road_category=None):  # noqa: E501
        """PrivateStreetNoticeResponse - a model defined in Swagger"""  # noqa: E501
        self._private_street_reference_number = None
        self._proposed_start_date = None
        self._proposed_end_date = None
        self._private_street_status = None
        self._private_street_status_string = None
        self._work_reference_number = None
        self._promoter_organisation = None
        self._promoter_swa_code = None
        self._secondary_contact = None
        self._secondary_contact_number = None
        self._secondary_contact_email = None
        self._proposed_start_time = None
        self._proposed_end_time = None
        self._calendar_day_duration = None
        self._working_day_duration = None
        self._description_of_work = None
        self._excavation = None
        self._project_reference_number = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._usrn = None
        self._highway_authority = None
        self._highway_authority_swa_code = None
        self._works_location_description = None
        self._works_coordinates = None
        self._date_created = None
        self._date_modified = None
        self._traffic_management_type = None
        self._traffic_management_type_string = None
        self._location_types = None
        self._location_types_string = None
        self._files = None
        self._workstream_prefix = None
        self._close_footway = None
        self._close_footway_string = None
        self._work_status = None
        self._work_status_string = None
        self._additional_contact = None
        self._additional_contact_number = None
        self._additional_contact_email = None
        self._emergency_contact_name = None
        self._emergency_contact_number = None
        self._close_footpath = None
        self._close_footpath_string = None
        self._street_line = None
        self._road_category = None
        self.discriminator = None
        self.private_street_reference_number = private_street_reference_number
        self.proposed_start_date = proposed_start_date
        self.proposed_end_date = proposed_end_date
        self.private_street_status = private_street_status
        self.private_street_status_string = private_street_status_string
        self.work_reference_number = work_reference_number
        self.promoter_organisation = promoter_organisation
        self.promoter_swa_code = promoter_swa_code
        self.secondary_contact = secondary_contact
        self.secondary_contact_number = secondary_contact_number
        if secondary_contact_email is not None:
            self.secondary_contact_email = secondary_contact_email
        if proposed_start_time is not None:
            self.proposed_start_time = proposed_start_time
        if proposed_end_time is not None:
            self.proposed_end_time = proposed_end_time
        self.calendar_day_duration = calendar_day_duration
        self.working_day_duration = working_day_duration
        self.description_of_work = description_of_work
        self.excavation = excavation
        if project_reference_number is not None:
            self.project_reference_number = project_reference_number
        self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.usrn = usrn
        self.highway_authority = highway_authority
        self.highway_authority_swa_code = highway_authority_swa_code
        self.works_location_description = works_location_description
        self.works_coordinates = works_coordinates
        self.date_created = date_created
        self.date_modified = date_modified
        self.traffic_management_type = traffic_management_type
        self.traffic_management_type_string = traffic_management_type_string
        self.location_types = location_types
        self.location_types_string = location_types_string
        if files is not None:
            self.files = files
        self.workstream_prefix = workstream_prefix
        self.close_footway = close_footway
        self.close_footway_string = close_footway_string
        self.work_status = work_status
        self.work_status_string = work_status_string
        if additional_contact is not None:
            self.additional_contact = additional_contact
        if additional_contact_number is not None:
            self.additional_contact_number = additional_contact_number
        if additional_contact_email is not None:
            self.additional_contact_email = additional_contact_email
        if emergency_contact_name is not None:
            self.emergency_contact_name = emergency_contact_name
        if emergency_contact_number is not None:
            self.emergency_contact_number = emergency_contact_number
        self.close_footpath = close_footpath
        self.close_footpath_string = close_footpath_string
        if street_line is not None:
            self.street_line = street_line
        self.road_category = road_category

    @property
    def private_street_reference_number(self):
        """Gets the private_street_reference_number of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The private_street_reference_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._private_street_reference_number

    @private_street_reference_number.setter
    def private_street_reference_number(self, private_street_reference_number):
        """Sets the private_street_reference_number of this PrivateStreetNoticeResponse.


        :param private_street_reference_number: The private_street_reference_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if private_street_reference_number is None:
            raise ValueError("Invalid value for `private_street_reference_number`, must not be `None`")  # noqa: E501

        self._private_street_reference_number = private_street_reference_number

    @property
    def proposed_start_date(self):
        """Gets the proposed_start_date of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The proposed_start_date of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_start_date

    @proposed_start_date.setter
    def proposed_start_date(self, proposed_start_date):
        """Sets the proposed_start_date of this PrivateStreetNoticeResponse.


        :param proposed_start_date: The proposed_start_date of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: datetime
        """
        if proposed_start_date is None:
            raise ValueError("Invalid value for `proposed_start_date`, must not be `None`")  # noqa: E501

        self._proposed_start_date = proposed_start_date

    @property
    def proposed_end_date(self):
        """Gets the proposed_end_date of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The proposed_end_date of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_end_date

    @proposed_end_date.setter
    def proposed_end_date(self, proposed_end_date):
        """Sets the proposed_end_date of this PrivateStreetNoticeResponse.


        :param proposed_end_date: The proposed_end_date of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: datetime
        """
        if proposed_end_date is None:
            raise ValueError("Invalid value for `proposed_end_date`, must not be `None`")  # noqa: E501

        self._proposed_end_date = proposed_end_date

    @property
    def private_street_status(self):
        """Gets the private_street_status of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The private_street_status of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: PrivateStreetStatusResponse
        """
        return self._private_street_status

    @private_street_status.setter
    def private_street_status(self, private_street_status):
        """Sets the private_street_status of this PrivateStreetNoticeResponse.


        :param private_street_status: The private_street_status of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: PrivateStreetStatusResponse
        """
        if private_street_status is None:
            raise ValueError("Invalid value for `private_street_status`, must not be `None`")  # noqa: E501

        self._private_street_status = private_street_status

    @property
    def private_street_status_string(self):
        """Gets the private_street_status_string of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The private_street_status_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._private_street_status_string

    @private_street_status_string.setter
    def private_street_status_string(self, private_street_status_string):
        """Sets the private_street_status_string of this PrivateStreetNoticeResponse.


        :param private_street_status_string: The private_street_status_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if private_street_status_string is None:
            raise ValueError("Invalid value for `private_street_status_string`, must not be `None`")  # noqa: E501

        self._private_street_status_string = private_street_status_string

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The work_reference_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this PrivateStreetNoticeResponse.


        :param work_reference_number: The work_reference_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if work_reference_number is None:
            raise ValueError("Invalid value for `work_reference_number`, must not be `None`")  # noqa: E501

        self._work_reference_number = work_reference_number

    @property
    def promoter_organisation(self):
        """Gets the promoter_organisation of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The promoter_organisation of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_organisation

    @promoter_organisation.setter
    def promoter_organisation(self, promoter_organisation):
        """Sets the promoter_organisation of this PrivateStreetNoticeResponse.


        :param promoter_organisation: The promoter_organisation of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if promoter_organisation is None:
            raise ValueError("Invalid value for `promoter_organisation`, must not be `None`")  # noqa: E501

        self._promoter_organisation = promoter_organisation

    @property
    def promoter_swa_code(self):
        """Gets the promoter_swa_code of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The promoter_swa_code of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_swa_code

    @promoter_swa_code.setter
    def promoter_swa_code(self, promoter_swa_code):
        """Sets the promoter_swa_code of this PrivateStreetNoticeResponse.


        :param promoter_swa_code: The promoter_swa_code of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if promoter_swa_code is None:
            raise ValueError("Invalid value for `promoter_swa_code`, must not be `None`")  # noqa: E501

        self._promoter_swa_code = promoter_swa_code

    @property
    def secondary_contact(self):
        """Gets the secondary_contact of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The secondary_contact of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._secondary_contact

    @secondary_contact.setter
    def secondary_contact(self, secondary_contact):
        """Sets the secondary_contact of this PrivateStreetNoticeResponse.


        :param secondary_contact: The secondary_contact of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if secondary_contact is None:
            raise ValueError("Invalid value for `secondary_contact`, must not be `None`")  # noqa: E501

        self._secondary_contact = secondary_contact

    @property
    def secondary_contact_number(self):
        """Gets the secondary_contact_number of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The secondary_contact_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._secondary_contact_number

    @secondary_contact_number.setter
    def secondary_contact_number(self, secondary_contact_number):
        """Sets the secondary_contact_number of this PrivateStreetNoticeResponse.


        :param secondary_contact_number: The secondary_contact_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if secondary_contact_number is None:
            raise ValueError("Invalid value for `secondary_contact_number`, must not be `None`")  # noqa: E501

        self._secondary_contact_number = secondary_contact_number

    @property
    def secondary_contact_email(self):
        """Gets the secondary_contact_email of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The secondary_contact_email of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._secondary_contact_email

    @secondary_contact_email.setter
    def secondary_contact_email(self, secondary_contact_email):
        """Sets the secondary_contact_email of this PrivateStreetNoticeResponse.


        :param secondary_contact_email: The secondary_contact_email of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """

        self._secondary_contact_email = secondary_contact_email

    @property
    def proposed_start_time(self):
        """Gets the proposed_start_time of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The proposed_start_time of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_start_time

    @proposed_start_time.setter
    def proposed_start_time(self, proposed_start_time):
        """Sets the proposed_start_time of this PrivateStreetNoticeResponse.


        :param proposed_start_time: The proposed_start_time of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: datetime
        """

        self._proposed_start_time = proposed_start_time

    @property
    def proposed_end_time(self):
        """Gets the proposed_end_time of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The proposed_end_time of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_end_time

    @proposed_end_time.setter
    def proposed_end_time(self, proposed_end_time):
        """Sets the proposed_end_time of this PrivateStreetNoticeResponse.


        :param proposed_end_time: The proposed_end_time of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: datetime
        """

        self._proposed_end_time = proposed_end_time

    @property
    def calendar_day_duration(self):
        """Gets the calendar_day_duration of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The calendar_day_duration of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: float
        """
        return self._calendar_day_duration

    @calendar_day_duration.setter
    def calendar_day_duration(self, calendar_day_duration):
        """Sets the calendar_day_duration of this PrivateStreetNoticeResponse.


        :param calendar_day_duration: The calendar_day_duration of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: float
        """
        if calendar_day_duration is None:
            raise ValueError("Invalid value for `calendar_day_duration`, must not be `None`")  # noqa: E501

        self._calendar_day_duration = calendar_day_duration

    @property
    def working_day_duration(self):
        """Gets the working_day_duration of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The working_day_duration of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: float
        """
        return self._working_day_duration

    @working_day_duration.setter
    def working_day_duration(self, working_day_duration):
        """Sets the working_day_duration of this PrivateStreetNoticeResponse.


        :param working_day_duration: The working_day_duration of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: float
        """
        if working_day_duration is None:
            raise ValueError("Invalid value for `working_day_duration`, must not be `None`")  # noqa: E501

        self._working_day_duration = working_day_duration

    @property
    def description_of_work(self):
        """Gets the description_of_work of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The description_of_work of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._description_of_work

    @description_of_work.setter
    def description_of_work(self, description_of_work):
        """Sets the description_of_work of this PrivateStreetNoticeResponse.


        :param description_of_work: The description_of_work of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if description_of_work is None:
            raise ValueError("Invalid value for `description_of_work`, must not be `None`")  # noqa: E501

        self._description_of_work = description_of_work

    @property
    def excavation(self):
        """Gets the excavation of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The excavation of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: bool
        """
        return self._excavation

    @excavation.setter
    def excavation(self, excavation):
        """Sets the excavation of this PrivateStreetNoticeResponse.


        :param excavation: The excavation of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: bool
        """
        if excavation is None:
            raise ValueError("Invalid value for `excavation`, must not be `None`")  # noqa: E501

        self._excavation = excavation

    @property
    def project_reference_number(self):
        """Gets the project_reference_number of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The project_reference_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._project_reference_number

    @project_reference_number.setter
    def project_reference_number(self, project_reference_number):
        """Sets the project_reference_number of this PrivateStreetNoticeResponse.


        :param project_reference_number: The project_reference_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """

        self._project_reference_number = project_reference_number

    @property
    def street_name(self):
        """Gets the street_name of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The street_name of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this PrivateStreetNoticeResponse.


        :param street_name: The street_name of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if street_name is None:
            raise ValueError("Invalid value for `street_name`, must not be `None`")  # noqa: E501

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The town of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this PrivateStreetNoticeResponse.


        :param town: The town of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The area_name of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this PrivateStreetNoticeResponse.


        :param area_name: The area_name of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def usrn(self):
        """Gets the usrn of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The usrn of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this PrivateStreetNoticeResponse.


        :param usrn: The usrn of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def highway_authority(self):
        """Gets the highway_authority of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The highway_authority of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority

    @highway_authority.setter
    def highway_authority(self, highway_authority):
        """Sets the highway_authority of this PrivateStreetNoticeResponse.


        :param highway_authority: The highway_authority of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if highway_authority is None:
            raise ValueError("Invalid value for `highway_authority`, must not be `None`")  # noqa: E501

        self._highway_authority = highway_authority

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The highway_authority_swa_code of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this PrivateStreetNoticeResponse.


        :param highway_authority_swa_code: The highway_authority_swa_code of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def works_location_description(self):
        """Gets the works_location_description of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The works_location_description of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._works_location_description

    @works_location_description.setter
    def works_location_description(self, works_location_description):
        """Sets the works_location_description of this PrivateStreetNoticeResponse.


        :param works_location_description: The works_location_description of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if works_location_description is None:
            raise ValueError("Invalid value for `works_location_description`, must not be `None`")  # noqa: E501

        self._works_location_description = works_location_description

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The works_coordinates of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this PrivateStreetNoticeResponse.


        :param works_coordinates: The works_coordinates of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def date_created(self):
        """Gets the date_created of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The date_created of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this PrivateStreetNoticeResponse.


        :param date_created: The date_created of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def date_modified(self):
        """Gets the date_modified of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The date_modified of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """Sets the date_modified of this PrivateStreetNoticeResponse.


        :param date_modified: The date_modified of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: datetime
        """
        if date_modified is None:
            raise ValueError("Invalid value for `date_modified`, must not be `None`")  # noqa: E501

        self._date_modified = date_modified

    @property
    def traffic_management_type(self):
        """Gets the traffic_management_type of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The traffic_management_type of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: TrafficManagementTypeResponse
        """
        return self._traffic_management_type

    @traffic_management_type.setter
    def traffic_management_type(self, traffic_management_type):
        """Sets the traffic_management_type of this PrivateStreetNoticeResponse.


        :param traffic_management_type: The traffic_management_type of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: TrafficManagementTypeResponse
        """
        if traffic_management_type is None:
            raise ValueError("Invalid value for `traffic_management_type`, must not be `None`")  # noqa: E501

        self._traffic_management_type = traffic_management_type

    @property
    def traffic_management_type_string(self):
        """Gets the traffic_management_type_string of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The traffic_management_type_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._traffic_management_type_string

    @traffic_management_type_string.setter
    def traffic_management_type_string(self, traffic_management_type_string):
        """Sets the traffic_management_type_string of this PrivateStreetNoticeResponse.


        :param traffic_management_type_string: The traffic_management_type_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if traffic_management_type_string is None:
            raise ValueError("Invalid value for `traffic_management_type_string`, must not be `None`")  # noqa: E501

        self._traffic_management_type_string = traffic_management_type_string

    @property
    def location_types(self):
        """Gets the location_types of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The location_types of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: list[LocationTypeResponse]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this PrivateStreetNoticeResponse.


        :param location_types: The location_types of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: list[LocationTypeResponse]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def location_types_string(self):
        """Gets the location_types_string of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The location_types_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._location_types_string

    @location_types_string.setter
    def location_types_string(self, location_types_string):
        """Sets the location_types_string of this PrivateStreetNoticeResponse.


        :param location_types_string: The location_types_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: list[str]
        """
        if location_types_string is None:
            raise ValueError("Invalid value for `location_types_string`, must not be `None`")  # noqa: E501

        self._location_types_string = location_types_string

    @property
    def files(self):
        """Gets the files of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The files of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: list[FileSummaryResponse]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this PrivateStreetNoticeResponse.


        :param files: The files of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: list[FileSummaryResponse]
        """

        self._files = files

    @property
    def workstream_prefix(self):
        """Gets the workstream_prefix of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The workstream_prefix of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._workstream_prefix

    @workstream_prefix.setter
    def workstream_prefix(self, workstream_prefix):
        """Sets the workstream_prefix of this PrivateStreetNoticeResponse.


        :param workstream_prefix: The workstream_prefix of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if workstream_prefix is None:
            raise ValueError("Invalid value for `workstream_prefix`, must not be `None`")  # noqa: E501

        self._workstream_prefix = workstream_prefix

    @property
    def close_footway(self):
        """Gets the close_footway of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The close_footway of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: CloseFootwayResponse
        """
        return self._close_footway

    @close_footway.setter
    def close_footway(self, close_footway):
        """Sets the close_footway of this PrivateStreetNoticeResponse.


        :param close_footway: The close_footway of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: CloseFootwayResponse
        """
        if close_footway is None:
            raise ValueError("Invalid value for `close_footway`, must not be `None`")  # noqa: E501

        self._close_footway = close_footway

    @property
    def close_footway_string(self):
        """Gets the close_footway_string of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The close_footway_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._close_footway_string

    @close_footway_string.setter
    def close_footway_string(self, close_footway_string):
        """Sets the close_footway_string of this PrivateStreetNoticeResponse.


        :param close_footway_string: The close_footway_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if close_footway_string is None:
            raise ValueError("Invalid value for `close_footway_string`, must not be `None`")  # noqa: E501

        self._close_footway_string = close_footway_string

    @property
    def work_status(self):
        """Gets the work_status of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The work_status of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: WorkStatusResponse
        """
        return self._work_status

    @work_status.setter
    def work_status(self, work_status):
        """Sets the work_status of this PrivateStreetNoticeResponse.


        :param work_status: The work_status of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: WorkStatusResponse
        """
        if work_status is None:
            raise ValueError("Invalid value for `work_status`, must not be `None`")  # noqa: E501

        self._work_status = work_status

    @property
    def work_status_string(self):
        """Gets the work_status_string of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The work_status_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._work_status_string

    @work_status_string.setter
    def work_status_string(self, work_status_string):
        """Sets the work_status_string of this PrivateStreetNoticeResponse.


        :param work_status_string: The work_status_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if work_status_string is None:
            raise ValueError("Invalid value for `work_status_string`, must not be `None`")  # noqa: E501

        self._work_status_string = work_status_string

    @property
    def additional_contact(self):
        """Gets the additional_contact of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The additional_contact of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._additional_contact

    @additional_contact.setter
    def additional_contact(self, additional_contact):
        """Sets the additional_contact of this PrivateStreetNoticeResponse.


        :param additional_contact: The additional_contact of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """

        self._additional_contact = additional_contact

    @property
    def additional_contact_number(self):
        """Gets the additional_contact_number of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The additional_contact_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._additional_contact_number

    @additional_contact_number.setter
    def additional_contact_number(self, additional_contact_number):
        """Sets the additional_contact_number of this PrivateStreetNoticeResponse.


        :param additional_contact_number: The additional_contact_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """

        self._additional_contact_number = additional_contact_number

    @property
    def additional_contact_email(self):
        """Gets the additional_contact_email of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The additional_contact_email of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._additional_contact_email

    @additional_contact_email.setter
    def additional_contact_email(self, additional_contact_email):
        """Sets the additional_contact_email of this PrivateStreetNoticeResponse.


        :param additional_contact_email: The additional_contact_email of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """

        self._additional_contact_email = additional_contact_email

    @property
    def emergency_contact_name(self):
        """Gets the emergency_contact_name of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The emergency_contact_name of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._emergency_contact_name

    @emergency_contact_name.setter
    def emergency_contact_name(self, emergency_contact_name):
        """Sets the emergency_contact_name of this PrivateStreetNoticeResponse.


        :param emergency_contact_name: The emergency_contact_name of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """

        self._emergency_contact_name = emergency_contact_name

    @property
    def emergency_contact_number(self):
        """Gets the emergency_contact_number of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The emergency_contact_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._emergency_contact_number

    @emergency_contact_number.setter
    def emergency_contact_number(self, emergency_contact_number):
        """Sets the emergency_contact_number of this PrivateStreetNoticeResponse.


        :param emergency_contact_number: The emergency_contact_number of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """

        self._emergency_contact_number = emergency_contact_number

    @property
    def close_footpath(self):
        """Gets the close_footpath of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The close_footpath of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: CloseFootpathResponse
        """
        return self._close_footpath

    @close_footpath.setter
    def close_footpath(self, close_footpath):
        """Sets the close_footpath of this PrivateStreetNoticeResponse.


        :param close_footpath: The close_footpath of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: CloseFootpathResponse
        """
        if close_footpath is None:
            raise ValueError("Invalid value for `close_footpath`, must not be `None`")  # noqa: E501

        self._close_footpath = close_footpath

    @property
    def close_footpath_string(self):
        """Gets the close_footpath_string of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The close_footpath_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: str
        """
        return self._close_footpath_string

    @close_footpath_string.setter
    def close_footpath_string(self, close_footpath_string):
        """Sets the close_footpath_string of this PrivateStreetNoticeResponse.


        :param close_footpath_string: The close_footpath_string of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: str
        """
        if close_footpath_string is None:
            raise ValueError("Invalid value for `close_footpath_string`, must not be `None`")  # noqa: E501

        self._close_footpath_string = close_footpath_string

    @property
    def street_line(self):
        """Gets the street_line of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The street_line of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: object
        """
        return self._street_line

    @street_line.setter
    def street_line(self, street_line):
        """Sets the street_line of this PrivateStreetNoticeResponse.


        :param street_line: The street_line of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: object
        """

        self._street_line = street_line

    @property
    def road_category(self):
        """Gets the road_category of this PrivateStreetNoticeResponse.  # noqa: E501


        :return: The road_category of this PrivateStreetNoticeResponse.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this PrivateStreetNoticeResponse.


        :param road_category: The road_category of this PrivateStreetNoticeResponse.  # noqa: E501
        :type: float
        """
        if road_category is None:
            raise ValueError("Invalid value for `road_category`, must not be `None`")  # noqa: E501

        self._road_category = road_category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PrivateStreetNoticeResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrivateStreetNoticeResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PermitAlterationStatusUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'alteration_status': 'AlterationStatus',
        'assessment_comments': 'str',
        'assessment_discount': 'float',
        'reasonable_period_end_date': 'datetime'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'alteration_status': 'alteration_status',
        'assessment_comments': 'assessment_comments',
        'assessment_discount': 'assessment_discount',
        'reasonable_period_end_date': 'reasonable_period_end_date'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, alteration_status=None, assessment_comments=None, assessment_discount=None, reasonable_period_end_date=None):  # noqa: E501
        """PermitAlterationStatusUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._alteration_status = None
        self._assessment_comments = None
        self._assessment_discount = None
        self._reasonable_period_end_date = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.alteration_status = alteration_status
        if assessment_comments is not None:
            self.assessment_comments = assessment_comments
        if assessment_discount is not None:
            self.assessment_discount = assessment_discount
        if reasonable_period_end_date is not None:
            self.reasonable_period_end_date = reasonable_period_end_date

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this PermitAlterationStatusUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this PermitAlterationStatusUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this PermitAlterationStatusUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this PermitAlterationStatusUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def alteration_status(self):
        """Gets the alteration_status of this PermitAlterationStatusUpdateRequest.  # noqa: E501


        :return: The alteration_status of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :rtype: AlterationStatus
        """
        return self._alteration_status

    @alteration_status.setter
    def alteration_status(self, alteration_status):
        """Sets the alteration_status of this PermitAlterationStatusUpdateRequest.


        :param alteration_status: The alteration_status of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :type: AlterationStatus
        """
        if alteration_status is None:
            raise ValueError("Invalid value for `alteration_status`, must not be `None`")  # noqa: E501

        self._alteration_status = alteration_status

    @property
    def assessment_comments(self):
        """Gets the assessment_comments of this PermitAlterationStatusUpdateRequest.  # noqa: E501

        Required if alteration_status = refused or granted_with_duration_challenge Max length 1500 characters  # noqa: E501

        :return: The assessment_comments of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._assessment_comments

    @assessment_comments.setter
    def assessment_comments(self, assessment_comments):
        """Sets the assessment_comments of this PermitAlterationStatusUpdateRequest.

        Required if alteration_status = refused or granted_with_duration_challenge Max length 1500 characters  # noqa: E501

        :param assessment_comments: The assessment_comments of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._assessment_comments = assessment_comments

    @property
    def assessment_discount(self):
        """Gets the assessment_discount of this PermitAlterationStatusUpdateRequest.  # noqa: E501

        Required if alteration_status = granted Is whole number between 0 and 100 inclusive  # noqa: E501

        :return: The assessment_discount of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._assessment_discount

    @assessment_discount.setter
    def assessment_discount(self, assessment_discount):
        """Sets the assessment_discount of this PermitAlterationStatusUpdateRequest.

        Required if alteration_status = granted Is whole number between 0 and 100 inclusive  # noqa: E501

        :param assessment_discount: The assessment_discount of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :type: float
        """

        self._assessment_discount = assessment_discount

    @property
    def reasonable_period_end_date(self):
        """Gets the reasonable_period_end_date of this PermitAlterationStatusUpdateRequest.  # noqa: E501

        Required if alteration_status = granted_with_duration_challenge Must be on or after the permit proposed_end_date and before the alteration updated proposed_end_date  # noqa: E501

        :return: The reasonable_period_end_date of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reasonable_period_end_date

    @reasonable_period_end_date.setter
    def reasonable_period_end_date(self, reasonable_period_end_date):
        """Sets the reasonable_period_end_date of this PermitAlterationStatusUpdateRequest.

        Required if alteration_status = granted_with_duration_challenge Must be on or after the permit proposed_end_date and before the alteration updated proposed_end_date  # noqa: E501

        :param reasonable_period_end_date: The reasonable_period_end_date of this PermitAlterationStatusUpdateRequest.  # noqa: E501
        :type: datetime
        """

        self._reasonable_period_end_date = reasonable_period_end_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PermitAlterationStatusUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PermitAlterationStatusUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PermitAssessmentUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'assessment_status': 'AssessmentStatus',
        'additional_comments': 'str',
        'reasons_for_refusal': 'list[ReasonForRefusal]',
        'assessment_discount': 'float',
        'revoke_reason': 'str',
        'pending_change_details': 'str',
        'reasonable_period_end_date': 'datetime',
        'is_duration_challenged': 'bool'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'assessment_status': 'assessment_status',
        'additional_comments': 'additional_comments',
        'reasons_for_refusal': 'reasons_for_refusal',
        'assessment_discount': 'assessment_discount',
        'revoke_reason': 'revoke_reason',
        'pending_change_details': 'pending_change_details',
        'reasonable_period_end_date': 'reasonable_period_end_date',
        'is_duration_challenged': 'is_duration_challenged'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, assessment_status=None, additional_comments=None, reasons_for_refusal=None, assessment_discount=None, revoke_reason=None, pending_change_details=None, reasonable_period_end_date=None, is_duration_challenged=None):  # noqa: E501
        """PermitAssessmentUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._assessment_status = None
        self._additional_comments = None
        self._reasons_for_refusal = None
        self._assessment_discount = None
        self._revoke_reason = None
        self._pending_change_details = None
        self._reasonable_period_end_date = None
        self._is_duration_challenged = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.assessment_status = assessment_status
        if additional_comments is not None:
            self.additional_comments = additional_comments
        if reasons_for_refusal is not None:
            self.reasons_for_refusal = reasons_for_refusal
        if assessment_discount is not None:
            self.assessment_discount = assessment_discount
        if revoke_reason is not None:
            self.revoke_reason = revoke_reason
        if pending_change_details is not None:
            self.pending_change_details = pending_change_details
        if reasonable_period_end_date is not None:
            self.reasonable_period_end_date = reasonable_period_end_date
        if is_duration_challenged is not None:
            self.is_duration_challenged = is_duration_challenged

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this PermitAssessmentUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this PermitAssessmentUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this PermitAssessmentUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this PermitAssessmentUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def assessment_status(self):
        """Gets the assessment_status of this PermitAssessmentUpdateRequest.  # noqa: E501


        :return: The assessment_status of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: AssessmentStatus
        """
        return self._assessment_status

    @assessment_status.setter
    def assessment_status(self, assessment_status):
        """Sets the assessment_status of this PermitAssessmentUpdateRequest.


        :param assessment_status: The assessment_status of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: AssessmentStatus
        """
        if assessment_status is None:
            raise ValueError("Invalid value for `assessment_status`, must not be `None`")  # noqa: E501

        self._assessment_status = assessment_status

    @property
    def additional_comments(self):
        """Gets the additional_comments of this PermitAssessmentUpdateRequest.  # noqa: E501

        Required if assessment_status = refused or is_duration_challenged = true Max length 1500 characters  # noqa: E501

        :return: The additional_comments of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._additional_comments

    @additional_comments.setter
    def additional_comments(self, additional_comments):
        """Sets the additional_comments of this PermitAssessmentUpdateRequest.

        Required if assessment_status = refused or is_duration_challenged = true Max length 1500 characters  # noqa: E501

        :param additional_comments: The additional_comments of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: str
        """

        self._additional_comments = additional_comments

    @property
    def reasons_for_refusal(self):
        """Gets the reasons_for_refusal of this PermitAssessmentUpdateRequest.  # noqa: E501

        Array values must be unique Must contain between 1 and 5 values Required if assessment_status = refused  # noqa: E501

        :return: The reasons_for_refusal of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: list[ReasonForRefusal]
        """
        return self._reasons_for_refusal

    @reasons_for_refusal.setter
    def reasons_for_refusal(self, reasons_for_refusal):
        """Sets the reasons_for_refusal of this PermitAssessmentUpdateRequest.

        Array values must be unique Must contain between 1 and 5 values Required if assessment_status = refused  # noqa: E501

        :param reasons_for_refusal: The reasons_for_refusal of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: list[ReasonForRefusal]
        """

        self._reasons_for_refusal = reasons_for_refusal

    @property
    def assessment_discount(self):
        """Gets the assessment_discount of this PermitAssessmentUpdateRequest.  # noqa: E501

        Required if assessment_status = granted and permit's work_category != hs2_highway Is whole number between 0 and 100 inclusive  # noqa: E501

        :return: The assessment_discount of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._assessment_discount

    @assessment_discount.setter
    def assessment_discount(self, assessment_discount):
        """Sets the assessment_discount of this PermitAssessmentUpdateRequest.

        Required if assessment_status = granted and permit's work_category != hs2_highway Is whole number between 0 and 100 inclusive  # noqa: E501

        :param assessment_discount: The assessment_discount of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: float
        """

        self._assessment_discount = assessment_discount

    @property
    def revoke_reason(self):
        """Gets the revoke_reason of this PermitAssessmentUpdateRequest.  # noqa: E501

        Required if assessment_status = revoked Max length 500 characters  # noqa: E501

        :return: The revoke_reason of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._revoke_reason

    @revoke_reason.setter
    def revoke_reason(self, revoke_reason):
        """Sets the revoke_reason of this PermitAssessmentUpdateRequest.

        Required if assessment_status = revoked Max length 500 characters  # noqa: E501

        :param revoke_reason: The revoke_reason of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: str
        """

        self._revoke_reason = revoke_reason

    @property
    def pending_change_details(self):
        """Gets the pending_change_details of this PermitAssessmentUpdateRequest.  # noqa: E501

        Required if assessment_status = permit_modification_request Max length 500 characters  # noqa: E501

        :return: The pending_change_details of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._pending_change_details

    @pending_change_details.setter
    def pending_change_details(self, pending_change_details):
        """Sets the pending_change_details of this PermitAssessmentUpdateRequest.

        Required if assessment_status = permit_modification_request Max length 500 characters  # noqa: E501

        :param pending_change_details: The pending_change_details of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: str
        """

        self._pending_change_details = pending_change_details

    @property
    def reasonable_period_end_date(self):
        """Gets the reasonable_period_end_date of this PermitAssessmentUpdateRequest.  # noqa: E501

        Required if is_duration_challenged = true Must be at least 2 working days from start date  # noqa: E501

        :return: The reasonable_period_end_date of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reasonable_period_end_date

    @reasonable_period_end_date.setter
    def reasonable_period_end_date(self, reasonable_period_end_date):
        """Sets the reasonable_period_end_date of this PermitAssessmentUpdateRequest.

        Required if is_duration_challenged = true Must be at least 2 working days from start date  # noqa: E501

        :param reasonable_period_end_date: The reasonable_period_end_date of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: datetime
        """

        self._reasonable_period_end_date = reasonable_period_end_date

    @property
    def is_duration_challenged(self):
        """Gets the is_duration_challenged of this PermitAssessmentUpdateRequest.  # noqa: E501


        :return: The is_duration_challenged of this PermitAssessmentUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_duration_challenged

    @is_duration_challenged.setter
    def is_duration_challenged(self, is_duration_challenged):
        """Sets the is_duration_challenged of this PermitAssessmentUpdateRequest.


        :param is_duration_challenged: The is_duration_challenged of this PermitAssessmentUpdateRequest.  # noqa: E501
        :type: bool
        """

        self._is_duration_challenged = is_duration_challenged

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PermitAssessmentUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PermitAssessmentUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FeeMatrixRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'major_paa_fee_traffic_sensitive': 'float',
        'major_work_permit_fee_traffic_sensitive': 'float',
        'standard_works_permit_fee_traffic_sensitive': 'float',
        'minor_works_permit_fee_traffic_sensitive': 'float',
        'immediate_works_permit_fee_traffic_sensitive': 'float',
        'permit_variation_fee_traffic_sensitive': 'float',
        'major_paa_fee_non_traffic_sensitive': 'float',
        'major_work_permit_fee_non_traffic_sensitive': 'float',
        'standard_works_permit_fee_non_traffic_sensitive': 'float',
        'minor_works_permit_fee_non_traffic_sensitive': 'float',
        'immediate_works_permit_fee_non_traffic_sensitive': 'float',
        'permit_variation_fee_non_traffic_sensitive': 'float',
        'discount_guidance': 'str'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'major_paa_fee_traffic_sensitive': 'major_paa_fee_traffic_sensitive',
        'major_work_permit_fee_traffic_sensitive': 'major_work_permit_fee_traffic_sensitive',
        'standard_works_permit_fee_traffic_sensitive': 'standard_works_permit_fee_traffic_sensitive',
        'minor_works_permit_fee_traffic_sensitive': 'minor_works_permit_fee_traffic_sensitive',
        'immediate_works_permit_fee_traffic_sensitive': 'immediate_works_permit_fee_traffic_sensitive',
        'permit_variation_fee_traffic_sensitive': 'permit_variation_fee_traffic_sensitive',
        'major_paa_fee_non_traffic_sensitive': 'major_paa_fee_non_traffic_sensitive',
        'major_work_permit_fee_non_traffic_sensitive': 'major_work_permit_fee_non_traffic_sensitive',
        'standard_works_permit_fee_non_traffic_sensitive': 'standard_works_permit_fee_non_traffic_sensitive',
        'minor_works_permit_fee_non_traffic_sensitive': 'minor_works_permit_fee_non_traffic_sensitive',
        'immediate_works_permit_fee_non_traffic_sensitive': 'immediate_works_permit_fee_non_traffic_sensitive',
        'permit_variation_fee_non_traffic_sensitive': 'permit_variation_fee_non_traffic_sensitive',
        'discount_guidance': 'discount_guidance'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, major_paa_fee_traffic_sensitive=None, major_work_permit_fee_traffic_sensitive=None, standard_works_permit_fee_traffic_sensitive=None, minor_works_permit_fee_traffic_sensitive=None, immediate_works_permit_fee_traffic_sensitive=None, permit_variation_fee_traffic_sensitive=None, major_paa_fee_non_traffic_sensitive=None, major_work_permit_fee_non_traffic_sensitive=None, standard_works_permit_fee_non_traffic_sensitive=None, minor_works_permit_fee_non_traffic_sensitive=None, immediate_works_permit_fee_non_traffic_sensitive=None, permit_variation_fee_non_traffic_sensitive=None, discount_guidance=None):  # noqa: E501
        """FeeMatrixRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._major_paa_fee_traffic_sensitive = None
        self._major_work_permit_fee_traffic_sensitive = None
        self._standard_works_permit_fee_traffic_sensitive = None
        self._minor_works_permit_fee_traffic_sensitive = None
        self._immediate_works_permit_fee_traffic_sensitive = None
        self._permit_variation_fee_traffic_sensitive = None
        self._major_paa_fee_non_traffic_sensitive = None
        self._major_work_permit_fee_non_traffic_sensitive = None
        self._standard_works_permit_fee_non_traffic_sensitive = None
        self._minor_works_permit_fee_non_traffic_sensitive = None
        self._immediate_works_permit_fee_non_traffic_sensitive = None
        self._permit_variation_fee_non_traffic_sensitive = None
        self._discount_guidance = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.major_paa_fee_traffic_sensitive = major_paa_fee_traffic_sensitive
        self.major_work_permit_fee_traffic_sensitive = major_work_permit_fee_traffic_sensitive
        self.standard_works_permit_fee_traffic_sensitive = standard_works_permit_fee_traffic_sensitive
        self.minor_works_permit_fee_traffic_sensitive = minor_works_permit_fee_traffic_sensitive
        self.immediate_works_permit_fee_traffic_sensitive = immediate_works_permit_fee_traffic_sensitive
        self.permit_variation_fee_traffic_sensitive = permit_variation_fee_traffic_sensitive
        self.major_paa_fee_non_traffic_sensitive = major_paa_fee_non_traffic_sensitive
        self.major_work_permit_fee_non_traffic_sensitive = major_work_permit_fee_non_traffic_sensitive
        self.standard_works_permit_fee_non_traffic_sensitive = standard_works_permit_fee_non_traffic_sensitive
        self.minor_works_permit_fee_non_traffic_sensitive = minor_works_permit_fee_non_traffic_sensitive
        self.immediate_works_permit_fee_non_traffic_sensitive = immediate_works_permit_fee_non_traffic_sensitive
        self.permit_variation_fee_non_traffic_sensitive = permit_variation_fee_non_traffic_sensitive
        self.discount_guidance = discount_guidance

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this FeeMatrixRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this FeeMatrixRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this FeeMatrixRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this FeeMatrixRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this FeeMatrixRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this FeeMatrixRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this FeeMatrixRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this FeeMatrixRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def major_paa_fee_traffic_sensitive(self):
        """Gets the major_paa_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The major_paa_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._major_paa_fee_traffic_sensitive

    @major_paa_fee_traffic_sensitive.setter
    def major_paa_fee_traffic_sensitive(self, major_paa_fee_traffic_sensitive):
        """Sets the major_paa_fee_traffic_sensitive of this FeeMatrixRequest.


        :param major_paa_fee_traffic_sensitive: The major_paa_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if major_paa_fee_traffic_sensitive is None:
            raise ValueError("Invalid value for `major_paa_fee_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._major_paa_fee_traffic_sensitive = major_paa_fee_traffic_sensitive

    @property
    def major_work_permit_fee_traffic_sensitive(self):
        """Gets the major_work_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The major_work_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._major_work_permit_fee_traffic_sensitive

    @major_work_permit_fee_traffic_sensitive.setter
    def major_work_permit_fee_traffic_sensitive(self, major_work_permit_fee_traffic_sensitive):
        """Sets the major_work_permit_fee_traffic_sensitive of this FeeMatrixRequest.


        :param major_work_permit_fee_traffic_sensitive: The major_work_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if major_work_permit_fee_traffic_sensitive is None:
            raise ValueError("Invalid value for `major_work_permit_fee_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._major_work_permit_fee_traffic_sensitive = major_work_permit_fee_traffic_sensitive

    @property
    def standard_works_permit_fee_traffic_sensitive(self):
        """Gets the standard_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The standard_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._standard_works_permit_fee_traffic_sensitive

    @standard_works_permit_fee_traffic_sensitive.setter
    def standard_works_permit_fee_traffic_sensitive(self, standard_works_permit_fee_traffic_sensitive):
        """Sets the standard_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.


        :param standard_works_permit_fee_traffic_sensitive: The standard_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if standard_works_permit_fee_traffic_sensitive is None:
            raise ValueError("Invalid value for `standard_works_permit_fee_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._standard_works_permit_fee_traffic_sensitive = standard_works_permit_fee_traffic_sensitive

    @property
    def minor_works_permit_fee_traffic_sensitive(self):
        """Gets the minor_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The minor_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._minor_works_permit_fee_traffic_sensitive

    @minor_works_permit_fee_traffic_sensitive.setter
    def minor_works_permit_fee_traffic_sensitive(self, minor_works_permit_fee_traffic_sensitive):
        """Sets the minor_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.


        :param minor_works_permit_fee_traffic_sensitive: The minor_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if minor_works_permit_fee_traffic_sensitive is None:
            raise ValueError("Invalid value for `minor_works_permit_fee_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._minor_works_permit_fee_traffic_sensitive = minor_works_permit_fee_traffic_sensitive

    @property
    def immediate_works_permit_fee_traffic_sensitive(self):
        """Gets the immediate_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The immediate_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._immediate_works_permit_fee_traffic_sensitive

    @immediate_works_permit_fee_traffic_sensitive.setter
    def immediate_works_permit_fee_traffic_sensitive(self, immediate_works_permit_fee_traffic_sensitive):
        """Sets the immediate_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.


        :param immediate_works_permit_fee_traffic_sensitive: The immediate_works_permit_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if immediate_works_permit_fee_traffic_sensitive is None:
            raise ValueError("Invalid value for `immediate_works_permit_fee_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._immediate_works_permit_fee_traffic_sensitive = immediate_works_permit_fee_traffic_sensitive

    @property
    def permit_variation_fee_traffic_sensitive(self):
        """Gets the permit_variation_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The permit_variation_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._permit_variation_fee_traffic_sensitive

    @permit_variation_fee_traffic_sensitive.setter
    def permit_variation_fee_traffic_sensitive(self, permit_variation_fee_traffic_sensitive):
        """Sets the permit_variation_fee_traffic_sensitive of this FeeMatrixRequest.


        :param permit_variation_fee_traffic_sensitive: The permit_variation_fee_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if permit_variation_fee_traffic_sensitive is None:
            raise ValueError("Invalid value for `permit_variation_fee_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._permit_variation_fee_traffic_sensitive = permit_variation_fee_traffic_sensitive

    @property
    def major_paa_fee_non_traffic_sensitive(self):
        """Gets the major_paa_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The major_paa_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._major_paa_fee_non_traffic_sensitive

    @major_paa_fee_non_traffic_sensitive.setter
    def major_paa_fee_non_traffic_sensitive(self, major_paa_fee_non_traffic_sensitive):
        """Sets the major_paa_fee_non_traffic_sensitive of this FeeMatrixRequest.


        :param major_paa_fee_non_traffic_sensitive: The major_paa_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if major_paa_fee_non_traffic_sensitive is None:
            raise ValueError("Invalid value for `major_paa_fee_non_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._major_paa_fee_non_traffic_sensitive = major_paa_fee_non_traffic_sensitive

    @property
    def major_work_permit_fee_non_traffic_sensitive(self):
        """Gets the major_work_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The major_work_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._major_work_permit_fee_non_traffic_sensitive

    @major_work_permit_fee_non_traffic_sensitive.setter
    def major_work_permit_fee_non_traffic_sensitive(self, major_work_permit_fee_non_traffic_sensitive):
        """Sets the major_work_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.


        :param major_work_permit_fee_non_traffic_sensitive: The major_work_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if major_work_permit_fee_non_traffic_sensitive is None:
            raise ValueError("Invalid value for `major_work_permit_fee_non_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._major_work_permit_fee_non_traffic_sensitive = major_work_permit_fee_non_traffic_sensitive

    @property
    def standard_works_permit_fee_non_traffic_sensitive(self):
        """Gets the standard_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The standard_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._standard_works_permit_fee_non_traffic_sensitive

    @standard_works_permit_fee_non_traffic_sensitive.setter
    def standard_works_permit_fee_non_traffic_sensitive(self, standard_works_permit_fee_non_traffic_sensitive):
        """Sets the standard_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.


        :param standard_works_permit_fee_non_traffic_sensitive: The standard_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if standard_works_permit_fee_non_traffic_sensitive is None:
            raise ValueError("Invalid value for `standard_works_permit_fee_non_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._standard_works_permit_fee_non_traffic_sensitive = standard_works_permit_fee_non_traffic_sensitive

    @property
    def minor_works_permit_fee_non_traffic_sensitive(self):
        """Gets the minor_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The minor_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._minor_works_permit_fee_non_traffic_sensitive

    @minor_works_permit_fee_non_traffic_sensitive.setter
    def minor_works_permit_fee_non_traffic_sensitive(self, minor_works_permit_fee_non_traffic_sensitive):
        """Sets the minor_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.


        :param minor_works_permit_fee_non_traffic_sensitive: The minor_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if minor_works_permit_fee_non_traffic_sensitive is None:
            raise ValueError("Invalid value for `minor_works_permit_fee_non_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._minor_works_permit_fee_non_traffic_sensitive = minor_works_permit_fee_non_traffic_sensitive

    @property
    def immediate_works_permit_fee_non_traffic_sensitive(self):
        """Gets the immediate_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The immediate_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._immediate_works_permit_fee_non_traffic_sensitive

    @immediate_works_permit_fee_non_traffic_sensitive.setter
    def immediate_works_permit_fee_non_traffic_sensitive(self, immediate_works_permit_fee_non_traffic_sensitive):
        """Sets the immediate_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.


        :param immediate_works_permit_fee_non_traffic_sensitive: The immediate_works_permit_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if immediate_works_permit_fee_non_traffic_sensitive is None:
            raise ValueError("Invalid value for `immediate_works_permit_fee_non_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._immediate_works_permit_fee_non_traffic_sensitive = immediate_works_permit_fee_non_traffic_sensitive

    @property
    def permit_variation_fee_non_traffic_sensitive(self):
        """Gets the permit_variation_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501


        :return: The permit_variation_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :rtype: float
        """
        return self._permit_variation_fee_non_traffic_sensitive

    @permit_variation_fee_non_traffic_sensitive.setter
    def permit_variation_fee_non_traffic_sensitive(self, permit_variation_fee_non_traffic_sensitive):
        """Sets the permit_variation_fee_non_traffic_sensitive of this FeeMatrixRequest.


        :param permit_variation_fee_non_traffic_sensitive: The permit_variation_fee_non_traffic_sensitive of this FeeMatrixRequest.  # noqa: E501
        :type: float
        """
        if permit_variation_fee_non_traffic_sensitive is None:
            raise ValueError("Invalid value for `permit_variation_fee_non_traffic_sensitive`, must not be `None`")  # noqa: E501

        self._permit_variation_fee_non_traffic_sensitive = permit_variation_fee_non_traffic_sensitive

    @property
    def discount_guidance(self):
        """Gets the discount_guidance of this FeeMatrixRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The discount_guidance of this FeeMatrixRequest.  # noqa: E501
        :rtype: str
        """
        return self._discount_guidance

    @discount_guidance.setter
    def discount_guidance(self, discount_guidance):
        """Sets the discount_guidance of this FeeMatrixRequest.

        Max length 500 characters  # noqa: E501

        :param discount_guidance: The discount_guidance of this FeeMatrixRequest.  # noqa: E501
        :type: str
        """
        if discount_guidance is None:
            raise ValueError("Invalid value for `discount_guidance`, must not be `None`")  # noqa: E501

        self._discount_guidance = discount_guidance

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FeeMatrixRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeeMatrixRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#!/usr/bin/env python3
"""
Script to fix swagger client imports by converting absolute imports to relative imports.
This script processes Python files within each 'swagger_client' directory
(e.g., src/streetmanager/work/swagger_client, src/streetmanager/geojson/swagger_client, etc.).

For each Python file, it:
1. Calculates the necessary relative import prefix ('.', '..', etc.) based on the
   file's depth relative to its 'swagger_client' root directory.
2. Provides specific, robust fixes for 'swagger_client/__init__.py' and
   'swagger_client/api/__init__.py' to ensure correct package structure.
3. For all other files, converts absolute imports like 'from swagger_client.module import Name'
   to 'from <prefix>.module import Name'.
"""

import re
from pathlib import Path

def convert_imports_in_file(file_path: Path, swagger_client_root: Path, project_root: Path):
    """
    Converts absolute 'swagger_client.' imports to relative imports in a single file.
    Prioritizes specific fixes for __init__.py files.
    """
    try:
        content = file_path.read_text(encoding='utf-8')
    except Exception as e:
        print(f"Error reading file {file_path}: {e}")
        return
    
    original_content = content
    current_filename = file_path.name
    current_file_parent_dir_name = file_path.parent.name
    is_in_swagger_client_root = (file_path.parent == swagger_client_root)
    is_in_api_subfolder = (current_file_parent_dir_name == "api" and file_path.parent.parent == swagger_client_root)

    # --- Specific fix for the main __init__.py of a swagger_client package ---
    # (e.g., src/streetmanager/work/swagger_client/__init__.py)
    if current_filename == "__init__.py" and is_in_swagger_client_root:
        # This __init__.py should expose DefaultApi from its 'api' subpackage.
        # Change "from .default_api import DefaultApi" (common from codegen) or
        # "from swagger_client.default_api import DefaultApi" or similar variations
        # to "from .api import DefaultApi".
        # This regex looks for the "# import apis into sdk package" comment block.
        content = re.sub(
            r'(# import apis into sdk package\\s*\\n\\s*from\\s+)(?:swagger_client\.|\.)(?:api\.)?default_api(\\s+import\\s+DefaultApi)',
            r'\\1.api\\2', # Ensures it becomes "from .api import DefaultApi"
            content,
            flags=re.IGNORECASE # To catch DefaultApi or defaultApi if casing varies
        )
        # Ensure other direct imports (api_client, configuration, models) are single-dot relative
        # if they were originally 'from swagger_client.X'
        content = re.sub(r'from swagger_client\\.api_client', 'from .api_client', content)
        content = re.sub(r'from swagger_client\\.configuration', 'from .configuration', content)
        content = re.sub(r'import swagger_client\\.api_client', 'import .api_client', content)
        content = re.sub(r'import swagger_client\\.configuration', 'import .configuration', content)
        content = re.sub(r'from swagger_client\\.models', 'from .models', content)
        content = re.sub(r'import swagger_client\\.models', 'import .models', content)

    # --- Specific fix for swagger_client/api/__init__.py ---
    elif current_filename == "__init__.py" and is_in_api_subfolder:
        # This file must import DefaultApi from its sibling default_api.py.
        # Change "from swagger_client.api.default_api import DefaultApi" (original codegen)
        # or "from ..api.default_api import DefaultApi" (potential previous incorrect fix)
        # or any other variation to "from .default_api import DefaultApi".
        # This regex looks for the "# import apis into api package" comment block.
        content = re.sub(
            r'(# import apis into api package\\s*\\n\\s*from\\s+)(?:swagger_client\.api\.|\.\.api\.|\.\.\.\.api\.|\.)default_api(\\s+import\\s+DefaultApi)',
            r'\\1.default_api\\2', # Ensures it becomes "from .default_api import DefaultApi"
            content,
            flags=re.IGNORECASE
        )
    
    # --- General rules for all other files ---
    else:
        try:
            relative_dir_of_file = file_path.parent.relative_to(swagger_client_root)
        except ValueError:
            print(f"Error: File {file_path} does not seem to be under swagger_client_root {swagger_client_root}")
            return
        depth = len(relative_dir_of_file.parts)
        dot_prefix = "." + "." * depth

        # Convert 'from swagger_client.sub.module' to 'from <dot_prefix>.sub.module'
        content = re.sub(r'from swagger_client\\.([\\w.]+)', rf'from {dot_prefix}.\\1', content)
        # Convert 'import swagger_client.sub.module' to 'import <dot_prefix>.sub.module'
        content = re.sub(r'import swagger_client\\.([\\w.]+)', rf'import {dot_prefix}.\\1', content)

    if content != original_content:
        print(f"Updating imports in: {file_path.relative_to(project_root)}")
        try:
            file_path.write_text(content, encoding='utf-8')
        except Exception as e:
            print(f"Error writing file {file_path}: {e}")
    else:
        print(f"No import changes needed for: {file_path.relative_to(project_root)}")

def main():
    # Determine the project root (assuming script is in 'scripts/' subdirectory of project root)
    try:
        project_root = Path(__file__).resolve().parent.parent
    except NameError: # Fallback if __file__ is not defined (e.g. interactive)
        project_root = Path(".").resolve()

    print(f"Project root identified as: {project_root}")
    base_src_dir = project_root / 'src' / 'streetmanager'

    submodule_types = ["work", "geojson", "lookup"]

    for submodule_name in submodule_types:
        swagger_client_root = base_src_dir / submodule_name / "swagger_client"
        if swagger_client_root.is_dir():
            print(f"\nProcessing swagger client module: {swagger_client_root.relative_to(project_root)}")
            
            python_files = list(swagger_client_root.rglob('*.py'))
            if not python_files:
                print(f"No Python files found in {swagger_client_root.relative_to(project_root)}")
                continue
            
            python_files.sort()

            for file_path in python_files:
                convert_imports_in_file(file_path, swagger_client_root, project_root)
        else:
            print(f"Directory not found, skipping: {swagger_client_root.relative_to(project_root)}")

    print("\nImport fixing process completed.")

if __name__ == '__main__':
    main() 


# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.hs2_highway_exemption import HS2HighwayExemption  # noqa: E501
from swagger_client.rest import ApiException


class TestHS2HighwayExemption(unittest.TestCase):
    """HS2HighwayExemption unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHS2HighwayExemption(self):
        """Test HS2HighwayExemption"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.hs2_highway_exemption.HS2HighwayExemption()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Section81CreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'promoter_swa_code': 'str',
        'highway_authority_swa_code': 'str',
        'works_coordinates': 'object',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'usrn': 'float',
        'road_category': 'float',
        'location_description': 'str',
        'location_types': 'list[LocationType]',
        'inspection_date': 'datetime',
        'section_81_type': 'Section81Type',
        'section_81_severity': 'AllOfSection81CreateRequestSection81Severity',
        'made_safe_by_ha': 'bool',
        'inspector_name': 'str',
        'inspector_contact_number': 'str',
        'additional_details': 'str',
        'other_type_details': 'str',
        'reinspection_date': 'datetime',
        'reinspection_date_time': 'datetime',
        'section_81_evidence': 'bool',
        'file_ids': 'list[float]'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'promoter_swa_code': 'promoter_swa_code',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'works_coordinates': 'works_coordinates',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'usrn': 'usrn',
        'road_category': 'road_category',
        'location_description': 'location_description',
        'location_types': 'location_types',
        'inspection_date': 'inspection_date',
        'section_81_type': 'section_81_type',
        'section_81_severity': 'section_81_severity',
        'made_safe_by_ha': 'made_safe_by_ha',
        'inspector_name': 'inspector_name',
        'inspector_contact_number': 'inspector_contact_number',
        'additional_details': 'additional_details',
        'other_type_details': 'other_type_details',
        'reinspection_date': 'reinspection_date',
        'reinspection_date_time': 'reinspection_date_time',
        'section_81_evidence': 'section_81_evidence',
        'file_ids': 'file_ids'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, promoter_swa_code=None, highway_authority_swa_code=None, works_coordinates=None, street_name=None, town=None, area_name=None, usrn=None, road_category=None, location_description=None, location_types=None, inspection_date=None, section_81_type=None, section_81_severity=None, made_safe_by_ha=None, inspector_name=None, inspector_contact_number=None, additional_details=None, other_type_details=None, reinspection_date=None, reinspection_date_time=None, section_81_evidence=None, file_ids=None):  # noqa: E501
        """Section81CreateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._promoter_swa_code = None
        self._highway_authority_swa_code = None
        self._works_coordinates = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._usrn = None
        self._road_category = None
        self._location_description = None
        self._location_types = None
        self._inspection_date = None
        self._section_81_type = None
        self._section_81_severity = None
        self._made_safe_by_ha = None
        self._inspector_name = None
        self._inspector_contact_number = None
        self._additional_details = None
        self._other_type_details = None
        self._reinspection_date = None
        self._reinspection_date_time = None
        self._section_81_evidence = None
        self._file_ids = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.promoter_swa_code = promoter_swa_code
        self.highway_authority_swa_code = highway_authority_swa_code
        self.works_coordinates = works_coordinates
        if street_name is not None:
            self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.usrn = usrn
        if road_category is not None:
            self.road_category = road_category
        self.location_description = location_description
        self.location_types = location_types
        self.inspection_date = inspection_date
        self.section_81_type = section_81_type
        if section_81_severity is not None:
            self.section_81_severity = section_81_severity
        if made_safe_by_ha is not None:
            self.made_safe_by_ha = made_safe_by_ha
        if inspector_name is not None:
            self.inspector_name = inspector_name
        if inspector_contact_number is not None:
            self.inspector_contact_number = inspector_contact_number
        self.additional_details = additional_details
        if other_type_details is not None:
            self.other_type_details = other_type_details
        if reinspection_date is not None:
            self.reinspection_date = reinspection_date
        if reinspection_date_time is not None:
            self.reinspection_date_time = reinspection_date_time
        self.section_81_evidence = section_81_evidence
        if file_ids is not None:
            self.file_ids = file_ids

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this Section81CreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this Section81CreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this Section81CreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this Section81CreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this Section81CreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this Section81CreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def promoter_swa_code(self):
        """Gets the promoter_swa_code of this Section81CreateRequest.  # noqa: E501

        Max length 4 characters  # noqa: E501

        :return: The promoter_swa_code of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._promoter_swa_code

    @promoter_swa_code.setter
    def promoter_swa_code(self, promoter_swa_code):
        """Sets the promoter_swa_code of this Section81CreateRequest.

        Max length 4 characters  # noqa: E501

        :param promoter_swa_code: The promoter_swa_code of this Section81CreateRequest.  # noqa: E501
        :type: str
        """
        if promoter_swa_code is None:
            raise ValueError("Invalid value for `promoter_swa_code`, must not be `None`")  # noqa: E501

        self._promoter_swa_code = promoter_swa_code

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this Section81CreateRequest.  # noqa: E501

        Max length 4 characters  # noqa: E501

        :return: The highway_authority_swa_code of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this Section81CreateRequest.

        Max length 4 characters  # noqa: E501

        :param highway_authority_swa_code: The highway_authority_swa_code of this Section81CreateRequest.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def works_coordinates(self):
        """Gets the works_coordinates of this Section81CreateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :return: The works_coordinates of this Section81CreateRequest.  # noqa: E501
        :rtype: object
        """
        return self._works_coordinates

    @works_coordinates.setter
    def works_coordinates(self, works_coordinates):
        """Sets the works_coordinates of this Section81CreateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point, line string or polygon  # noqa: E501

        :param works_coordinates: The works_coordinates of this Section81CreateRequest.  # noqa: E501
        :type: object
        """
        if works_coordinates is None:
            raise ValueError("Invalid value for `works_coordinates`, must not be `None`")  # noqa: E501

        self._works_coordinates = works_coordinates

    @property
    def street_name(self):
        """Gets the street_name of this Section81CreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The street_name of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this Section81CreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param street_name: The street_name of this Section81CreateRequest.  # noqa: E501
        :type: str
        """

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this Section81CreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The town of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this Section81CreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param town: The town of this Section81CreateRequest.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this Section81CreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The area_name of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this Section81CreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param area_name: The area_name of this Section81CreateRequest.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def usrn(self):
        """Gets the usrn of this Section81CreateRequest.  # noqa: E501

        Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN  # noqa: E501

        :return: The usrn of this Section81CreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this Section81CreateRequest.

        Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN  # noqa: E501

        :param usrn: The usrn of this Section81CreateRequest.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def road_category(self):
        """Gets the road_category of this Section81CreateRequest.  # noqa: E501

        Is whole number between 0 and 10 inclusive If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The road_category of this Section81CreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this Section81CreateRequest.

        Is whole number between 0 and 10 inclusive If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param road_category: The road_category of this Section81CreateRequest.  # noqa: E501
        :type: float
        """

        self._road_category = road_category

    @property
    def location_description(self):
        """Gets the location_description of this Section81CreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The location_description of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this Section81CreateRequest.

        Max length 500 characters  # noqa: E501

        :param location_description: The location_description of this Section81CreateRequest.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def location_types(self):
        """Gets the location_types of this Section81CreateRequest.  # noqa: E501

        Array values must be unique  # noqa: E501

        :return: The location_types of this Section81CreateRequest.  # noqa: E501
        :rtype: list[LocationType]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this Section81CreateRequest.

        Array values must be unique  # noqa: E501

        :param location_types: The location_types of this Section81CreateRequest.  # noqa: E501
        :type: list[LocationType]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def inspection_date(self):
        """Gets the inspection_date of this Section81CreateRequest.  # noqa: E501

        Date must be today or a date in the past  # noqa: E501

        :return: The inspection_date of this Section81CreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._inspection_date

    @inspection_date.setter
    def inspection_date(self, inspection_date):
        """Sets the inspection_date of this Section81CreateRequest.

        Date must be today or a date in the past  # noqa: E501

        :param inspection_date: The inspection_date of this Section81CreateRequest.  # noqa: E501
        :type: datetime
        """
        if inspection_date is None:
            raise ValueError("Invalid value for `inspection_date`, must not be `None`")  # noqa: E501

        self._inspection_date = inspection_date

    @property
    def section_81_type(self):
        """Gets the section_81_type of this Section81CreateRequest.  # noqa: E501


        :return: The section_81_type of this Section81CreateRequest.  # noqa: E501
        :rtype: Section81Type
        """
        return self._section_81_type

    @section_81_type.setter
    def section_81_type(self, section_81_type):
        """Sets the section_81_type of this Section81CreateRequest.


        :param section_81_type: The section_81_type of this Section81CreateRequest.  # noqa: E501
        :type: Section81Type
        """
        if section_81_type is None:
            raise ValueError("Invalid value for `section_81_type`, must not be `None`")  # noqa: E501

        self._section_81_type = section_81_type

    @property
    def section_81_severity(self):
        """Gets the section_81_severity of this Section81CreateRequest.  # noqa: E501

        Required if section_81_type is not unattributed_works_completed or unattributed_works_live_site  # noqa: E501

        :return: The section_81_severity of this Section81CreateRequest.  # noqa: E501
        :rtype: AllOfSection81CreateRequestSection81Severity
        """
        return self._section_81_severity

    @section_81_severity.setter
    def section_81_severity(self, section_81_severity):
        """Sets the section_81_severity of this Section81CreateRequest.

        Required if section_81_type is not unattributed_works_completed or unattributed_works_live_site  # noqa: E501

        :param section_81_severity: The section_81_severity of this Section81CreateRequest.  # noqa: E501
        :type: AllOfSection81CreateRequestSection81Severity
        """

        self._section_81_severity = section_81_severity

    @property
    def made_safe_by_ha(self):
        """Gets the made_safe_by_ha of this Section81CreateRequest.  # noqa: E501

        Required if section_81_type is not unattributed_works_completed or unattributed_works_live_site  # noqa: E501

        :return: The made_safe_by_ha of this Section81CreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._made_safe_by_ha

    @made_safe_by_ha.setter
    def made_safe_by_ha(self, made_safe_by_ha):
        """Sets the made_safe_by_ha of this Section81CreateRequest.

        Required if section_81_type is not unattributed_works_completed or unattributed_works_live_site  # noqa: E501

        :param made_safe_by_ha: The made_safe_by_ha of this Section81CreateRequest.  # noqa: E501
        :type: bool
        """

        self._made_safe_by_ha = made_safe_by_ha

    @property
    def inspector_name(self):
        """Gets the inspector_name of this Section81CreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The inspector_name of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._inspector_name

    @inspector_name.setter
    def inspector_name(self, inspector_name):
        """Sets the inspector_name of this Section81CreateRequest.

        Max length 100 characters  # noqa: E501

        :param inspector_name: The inspector_name of this Section81CreateRequest.  # noqa: E501
        :type: str
        """

        self._inspector_name = inspector_name

    @property
    def inspector_contact_number(self):
        """Gets the inspector_contact_number of this Section81CreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The inspector_contact_number of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._inspector_contact_number

    @inspector_contact_number.setter
    def inspector_contact_number(self, inspector_contact_number):
        """Sets the inspector_contact_number of this Section81CreateRequest.

        Max length 100 characters  # noqa: E501

        :param inspector_contact_number: The inspector_contact_number of this Section81CreateRequest.  # noqa: E501
        :type: str
        """

        self._inspector_contact_number = inspector_contact_number

    @property
    def additional_details(self):
        """Gets the additional_details of this Section81CreateRequest.  # noqa: E501

        Max length 500 characters  # noqa: E501

        :return: The additional_details of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._additional_details

    @additional_details.setter
    def additional_details(self, additional_details):
        """Sets the additional_details of this Section81CreateRequest.

        Max length 500 characters  # noqa: E501

        :param additional_details: The additional_details of this Section81CreateRequest.  # noqa: E501
        :type: str
        """
        if additional_details is None:
            raise ValueError("Invalid value for `additional_details`, must not be `None`")  # noqa: E501

        self._additional_details = additional_details

    @property
    def other_type_details(self):
        """Gets the other_type_details of this Section81CreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The other_type_details of this Section81CreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._other_type_details

    @other_type_details.setter
    def other_type_details(self, other_type_details):
        """Sets the other_type_details of this Section81CreateRequest.

        Max length 100 characters  # noqa: E501

        :param other_type_details: The other_type_details of this Section81CreateRequest.  # noqa: E501
        :type: str
        """

        self._other_type_details = other_type_details

    @property
    def reinspection_date(self):
        """Gets the reinspection_date of this Section81CreateRequest.  # noqa: E501

        Date must occur today or a date in the future  # noqa: E501

        :return: The reinspection_date of this Section81CreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reinspection_date

    @reinspection_date.setter
    def reinspection_date(self, reinspection_date):
        """Sets the reinspection_date of this Section81CreateRequest.

        Date must occur today or a date in the future  # noqa: E501

        :param reinspection_date: The reinspection_date of this Section81CreateRequest.  # noqa: E501
        :type: datetime
        """

        self._reinspection_date = reinspection_date

    @property
    def reinspection_date_time(self):
        """Gets the reinspection_date_time of this Section81CreateRequest.  # noqa: E501

        The date for reinspection_date_time must match the date for reinspection_date Time must occur today or a date in the future  # noqa: E501

        :return: The reinspection_date_time of this Section81CreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._reinspection_date_time

    @reinspection_date_time.setter
    def reinspection_date_time(self, reinspection_date_time):
        """Sets the reinspection_date_time of this Section81CreateRequest.

        The date for reinspection_date_time must match the date for reinspection_date Time must occur today or a date in the future  # noqa: E501

        :param reinspection_date_time: The reinspection_date_time of this Section81CreateRequest.  # noqa: E501
        :type: datetime
        """

        self._reinspection_date_time = reinspection_date_time

    @property
    def section_81_evidence(self):
        """Gets the section_81_evidence of this Section81CreateRequest.  # noqa: E501


        :return: The section_81_evidence of this Section81CreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._section_81_evidence

    @section_81_evidence.setter
    def section_81_evidence(self, section_81_evidence):
        """Sets the section_81_evidence of this Section81CreateRequest.


        :param section_81_evidence: The section_81_evidence of this Section81CreateRequest.  # noqa: E501
        :type: bool
        """
        if section_81_evidence is None:
            raise ValueError("Invalid value for `section_81_evidence`, must not be `None`")  # noqa: E501

        self._section_81_evidence = section_81_evidence

    @property
    def file_ids(self):
        """Gets the file_ids of this Section81CreateRequest.  # noqa: E501

        Required if section_81_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :return: The file_ids of this Section81CreateRequest.  # noqa: E501
        :rtype: list[float]
        """
        return self._file_ids

    @file_ids.setter
    def file_ids(self, file_ids):
        """Sets the file_ids of this Section81CreateRequest.

        Required if section_81_evidence = true Array values must be unique Must not contain null or undefined values A file_id can only be associated with one section of Street Manager See API specification Resource Guide > Works API > File upload for more information  # noqa: E501

        :param file_ids: The file_ids of this Section81CreateRequest.  # noqa: E501
        :type: list[float]
        """

        self._file_ids = file_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Section81CreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Section81CreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MaterialClassificationCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'highway_authority_swa_code': 'str',
        'material_classification_coordinates': 'object',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'usrn': 'float',
        'location_types': 'list[LocationType]',
        'file_id': 'float',
        'material_classification_classification': 'MaterialClassificationClassification',
        'hazardous_material_type': 'list[HazardousMaterialType]',
        'hazardous_material_type_other_description': 'str',
        'layer_affected': 'list[LayerAffected]',
        'sample_date': 'datetime',
        'location_description': 'str'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'highway_authority_swa_code': 'highway_authority_swa_code',
        'material_classification_coordinates': 'material_classification_coordinates',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'usrn': 'usrn',
        'location_types': 'location_types',
        'file_id': 'file_id',
        'material_classification_classification': 'material_classification_classification',
        'hazardous_material_type': 'hazardous_material_type',
        'hazardous_material_type_other_description': 'hazardous_material_type_other_description',
        'layer_affected': 'layer_affected',
        'sample_date': 'sample_date',
        'location_description': 'location_description'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, highway_authority_swa_code=None, material_classification_coordinates=None, street_name=None, town=None, area_name=None, usrn=None, location_types=None, file_id=None, material_classification_classification=None, hazardous_material_type=None, hazardous_material_type_other_description=None, layer_affected=None, sample_date=None, location_description=None):  # noqa: E501
        """MaterialClassificationCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._highway_authority_swa_code = None
        self._material_classification_coordinates = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._usrn = None
        self._location_types = None
        self._file_id = None
        self._material_classification_classification = None
        self._hazardous_material_type = None
        self._hazardous_material_type_other_description = None
        self._layer_affected = None
        self._sample_date = None
        self._location_description = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.highway_authority_swa_code = highway_authority_swa_code
        self.material_classification_coordinates = material_classification_coordinates
        if street_name is not None:
            self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        self.usrn = usrn
        self.location_types = location_types
        if file_id is not None:
            self.file_id = file_id
        self.material_classification_classification = material_classification_classification
        if hazardous_material_type is not None:
            self.hazardous_material_type = hazardous_material_type
        if hazardous_material_type_other_description is not None:
            self.hazardous_material_type_other_description = hazardous_material_type_other_description
        self.layer_affected = layer_affected
        self.sample_date = sample_date
        self.location_description = location_description

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this MaterialClassificationCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this MaterialClassificationCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this MaterialClassificationCreateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this MaterialClassificationCreateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this MaterialClassificationCreateRequest.  # noqa: E501

        Max length 4 characters  # noqa: E501

        :return: The highway_authority_swa_code of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this MaterialClassificationCreateRequest.

        Max length 4 characters  # noqa: E501

        :param highway_authority_swa_code: The highway_authority_swa_code of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    @property
    def material_classification_coordinates(self):
        """Gets the material_classification_coordinates of this MaterialClassificationCreateRequest.  # noqa: E501

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point Mandatory field Single GeoJSON Object  # noqa: E501

        :return: The material_classification_coordinates of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: object
        """
        return self._material_classification_coordinates

    @material_classification_coordinates.setter
    def material_classification_coordinates(self, material_classification_coordinates):
        """Sets the material_classification_coordinates of this MaterialClassificationCreateRequest.

        Must be a GeoJSON geometry (using British National Grid easting and northing coordinate pairs) and must be a point Mandatory field Single GeoJSON Object  # noqa: E501

        :param material_classification_coordinates: The material_classification_coordinates of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: object
        """
        if material_classification_coordinates is None:
            raise ValueError("Invalid value for `material_classification_coordinates`, must not be `None`")  # noqa: E501

        self._material_classification_coordinates = material_classification_coordinates

    @property
    def street_name(self):
        """Gets the street_name of this MaterialClassificationCreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The street_name of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this MaterialClassificationCreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param street_name: The street_name of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: str
        """

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this MaterialClassificationCreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The town of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this MaterialClassificationCreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param town: The town of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this MaterialClassificationCreateRequest.  # noqa: E501

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :return: The area_name of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this MaterialClassificationCreateRequest.

        Max length 100 characters Use Street Lookup API endpoint /nsg/streets to lookup this information If not provided, populated with NSG data related to supplied USRN  # noqa: E501

        :param area_name: The area_name of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def usrn(self):
        """Gets the usrn of this MaterialClassificationCreateRequest.  # noqa: E501

        Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN  # noqa: E501

        :return: The usrn of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this MaterialClassificationCreateRequest.

        Is whole number between 1000001 and 99999999 inclusive See business rules section 1.4 - USRN  # noqa: E501

        :param usrn: The usrn of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def location_types(self):
        """Gets the location_types of this MaterialClassificationCreateRequest.  # noqa: E501

        Array values must be unique  # noqa: E501

        :return: The location_types of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: list[LocationType]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this MaterialClassificationCreateRequest.

        Array values must be unique  # noqa: E501

        :param location_types: The location_types of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: list[LocationType]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def file_id(self):
        """Gets the file_id of this MaterialClassificationCreateRequest.  # noqa: E501

        Can only be one file Limited to 10MBs  # noqa: E501

        :return: The file_id of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._file_id

    @file_id.setter
    def file_id(self, file_id):
        """Sets the file_id of this MaterialClassificationCreateRequest.

        Can only be one file Limited to 10MBs  # noqa: E501

        :param file_id: The file_id of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: float
        """

        self._file_id = file_id

    @property
    def material_classification_classification(self):
        """Gets the material_classification_classification of this MaterialClassificationCreateRequest.  # noqa: E501


        :return: The material_classification_classification of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: MaterialClassificationClassification
        """
        return self._material_classification_classification

    @material_classification_classification.setter
    def material_classification_classification(self, material_classification_classification):
        """Sets the material_classification_classification of this MaterialClassificationCreateRequest.


        :param material_classification_classification: The material_classification_classification of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: MaterialClassificationClassification
        """
        if material_classification_classification is None:
            raise ValueError("Invalid value for `material_classification_classification`, must not be `None`")  # noqa: E501

        self._material_classification_classification = material_classification_classification

    @property
    def hazardous_material_type(self):
        """Gets the hazardous_material_type of this MaterialClassificationCreateRequest.  # noqa: E501

        Mandatory if material_classification_classification is hazardous  # noqa: E501

        :return: The hazardous_material_type of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: list[HazardousMaterialType]
        """
        return self._hazardous_material_type

    @hazardous_material_type.setter
    def hazardous_material_type(self, hazardous_material_type):
        """Sets the hazardous_material_type of this MaterialClassificationCreateRequest.

        Mandatory if material_classification_classification is hazardous  # noqa: E501

        :param hazardous_material_type: The hazardous_material_type of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: list[HazardousMaterialType]
        """

        self._hazardous_material_type = hazardous_material_type

    @property
    def hazardous_material_type_other_description(self):
        """Gets the hazardous_material_type_other_description of this MaterialClassificationCreateRequest.  # noqa: E501

        Mandatory if MaterialClassificationClassification is hazardous and hazardous_material_type is other Max 500 chars  # noqa: E501

        :return: The hazardous_material_type_other_description of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._hazardous_material_type_other_description

    @hazardous_material_type_other_description.setter
    def hazardous_material_type_other_description(self, hazardous_material_type_other_description):
        """Sets the hazardous_material_type_other_description of this MaterialClassificationCreateRequest.

        Mandatory if MaterialClassificationClassification is hazardous and hazardous_material_type is other Max 500 chars  # noqa: E501

        :param hazardous_material_type_other_description: The hazardous_material_type_other_description of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: str
        """

        self._hazardous_material_type_other_description = hazardous_material_type_other_description

    @property
    def layer_affected(self):
        """Gets the layer_affected of this MaterialClassificationCreateRequest.  # noqa: E501

        Mandatory  # noqa: E501

        :return: The layer_affected of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: list[LayerAffected]
        """
        return self._layer_affected

    @layer_affected.setter
    def layer_affected(self, layer_affected):
        """Sets the layer_affected of this MaterialClassificationCreateRequest.

        Mandatory  # noqa: E501

        :param layer_affected: The layer_affected of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: list[LayerAffected]
        """
        if layer_affected is None:
            raise ValueError("Invalid value for `layer_affected`, must not be `None`")  # noqa: E501

        self._layer_affected = layer_affected

    @property
    def sample_date(self):
        """Gets the sample_date of this MaterialClassificationCreateRequest.  # noqa: E501

        Mandatory Must be today or in the past  # noqa: E501

        :return: The sample_date of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._sample_date

    @sample_date.setter
    def sample_date(self, sample_date):
        """Sets the sample_date of this MaterialClassificationCreateRequest.

        Mandatory Must be today or in the past  # noqa: E501

        :param sample_date: The sample_date of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: datetime
        """
        if sample_date is None:
            raise ValueError("Invalid value for `sample_date`, must not be `None`")  # noqa: E501

        self._sample_date = sample_date

    @property
    def location_description(self):
        """Gets the location_description of this MaterialClassificationCreateRequest.  # noqa: E501

        Mandatory  # noqa: E501

        :return: The location_description of this MaterialClassificationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this MaterialClassificationCreateRequest.

        Mandatory  # noqa: E501

        :param location_description: The location_description of this MaterialClassificationCreateRequest.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MaterialClassificationCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MaterialClassificationCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
